
Django EL(Endless) Pagination
-----------------------------

This app **django-el-pagination**
created from django-endless-pagination==2.0 (https://github.com/frankban/django-endless-pagination)

I will try to provide support of this application
I am planning:
 - review the current pull requests from original repository
 - review the issues of original repository
 - create start version 2.1.0 with fixed critical bugs for today (for example Django 1.9 )
 - Add 2-5 contributors to help support the application
 Pull requests are welcome.

!WARNING! 
I use git flow. 
Please, change code and submit all pull requests into branch `develop`


Django EL(Endless) Pagination can be used to provide Twitter-style or
Digg-style pagination, with optional Ajax support and other features
like multiple or lazy pagination.

The initial idea, which has guided the development of this application,
is to allow pagination of web contents in `very few steps
<http://django-el-pagination.readthedocs.org/en/latest/start.html>`_.

**Documentation** is `avaliable online
<http://django-el-pagination.readthedocs.org/>`_, or in the doc
directory of the project.

To file **bugs and requests**, please use
https://github.com/shtalinberg/django-el-pagination/issues.

The **source code** for this app is hosted at
https://github.com/shtalinberg/django-el-pagination.

